Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-02-01 19:34:47 +0000
committerStijn Buys <ingar@osirion.org>2008-02-01 19:34:47 +0000
commit6c8446cddb37df732fc9e5fc21f98e31968ce634 (patch)
tree25515ae78969e2f0ef216a5cbef8a650b217e8f8 /src/client/client.h
parentf794b9ee52293cefd6ac73fdf0d2a01c5388f057 (diff)
interface cleanup
Diffstat (limited to 'src/client/client.h')
-rw-r--r--src/client/client.h49
1 files changed, 31 insertions, 18 deletions
diff --git a/src/client/client.h b/src/client/client.h
index a25643c..af3e53b 100644
--- a/src/client/client.h
+++ b/src/client/client.h
@@ -7,32 +7,45 @@
#ifndef __INCLUDED_CLIENT_H__
#define __INCLUDED_CLIENT_H__
-#include "client/console.h"
+// project headers
+#include "client/application.h"
#include "client/camera.h"
-#include "client/view.h"
+#include "client/console.h"
#include "client/input.h"
#include "client/video.h"
+#include "client/view.h"
+
+#include "core/core.h"
+#include "game/game.h"
/// client-side functions to render and control the gameworld
/** The client namespace contains the necessary functions to
* accept input, send it to the game and renders the result
*/
namespace client {
- /// initialize the client
- extern void init();
- /// run the client
- extern void run();
- /// shutdown the client
- extern void shutdown();
-
- /// global Video object
- extern Video video;
- /// global Input object
- extern Input input;
- /// global View object
- extern View view;
- /// global Camera object
- extern Camera camera;
-}
+
+/// global Application instance;
+extern Application application;
+
+/// global Video instance
+extern Video video;
+
+/// global Input instance
+extern Input input;
+
+/// global View instance
+extern View view;
+
+/// global Camera instance
+extern Camera camera;
+
+/// global server Console instance
+extern Console console;
+
+/// global Game instance
+extern game::Game game;
+
+} // namespace client
#endif // __INCLUDED_CLIENT_H__
+